package reformatKeyedData;
/**
 * Class KeyedClasses
 */

public class KeyedClasses {

  //
  // Fields
  //

	private static int defaultMaxNrKeyedClasses = 100;
	private static int nrFields = 5;
	private int nrKeyedClasses = 0;
	private String[] keyedClassNames;
	private DayOfWeek[] startDays; //Day of week class is held
	private HourOfDay[] startHours; //Hour class is held
	private String[] terms; //Terms when class is held
	private String[] rooms; //Room where class is held
	private String[] lecturers; //Lecturer teaching class
	private String[][] totalStructure; //All indformation for classes
  
  //
  // Constructors
  //
  public KeyedClasses () {
	  this.nrKeyedClasses = 0;
	  this.keyedClassNames = new String[defaultMaxNrKeyedClasses];
	  this.startDays = new DayOfWeek[defaultMaxNrKeyedClasses];
	  this.startHours = new HourOfDay[defaultMaxNrKeyedClasses];
	  this.terms = new String[defaultMaxNrKeyedClasses];
	  this.rooms = new String[defaultMaxNrKeyedClasses];
	  this.lecturers = new String[defaultMaxNrKeyedClasses];
	  this.totalStructure = new String[defaultMaxNrKeyedClasses][nrFields];
  }
  	
  public KeyedClasses (int maxNrKeyedClasses) {
	  this.nrKeyedClasses = 0;
	  this.keyedClassNames = new String[maxNrKeyedClasses];
	  this.startDays = new DayOfWeek[maxNrKeyedClasses];
	  this.startHours = new HourOfDay[maxNrKeyedClasses];
	  this.terms = new String[maxNrKeyedClasses];
	  this.rooms = new String[maxNrKeyedClasses];
	  this.lecturers = new String[maxNrKeyedClasses];
	  this.totalStructure = new String[maxNrKeyedClasses][nrFields];
  }
	  	
  //
  // Methods
  //


  //
  // Accessor methods
  //
  /**
   * Get the number of KeyedClasses
   * @return nrKeyedClasses
   */
  public int getNrKeyedClasses() {
	  return nrKeyedClasses;
  }
  
  /**
   * Get a specific keyedClassName
   * @return keyedClassName
   */
  public String getKeyedClassName(int indexItem) {
	  return keyedClassNames[indexItem];
  }

  /**
   * Get a specific keyedClass lecturer
   * @return lecturer
   */
  public String getKeyedClassLecturer(int indexItem) {
	  return lecturers[indexItem];
  }

  /**
   * Get a specific keyedClass room
   * @return room
   */
  public String getKeyedClassRoom(int indexItem) {
	  return rooms[indexItem];
  }

  /**
   * Get entire keyedClass structure
   * @return keyedClassName
   */
  public String[][] getKeyedClassStructure() {
	  return totalStructure;
  }
  //
  // Other methods
  //

  /**
   * Adds new class to arrays
   * @params       className, startDay, startTime, room, lecturer
   */
  public void addKeyedClass(String className, DayOfWeek startDay, HourOfDay startHour, 
		  String term, String room, String lecturer) {
	  if (this.isMember(className) == -1) {
		  this.keyedClassNames[nrKeyedClasses] = className;
		  this.startDays[nrKeyedClasses] = startDay;
		  this.startHours[nrKeyedClasses] = startHour;
		  this.terms[nrKeyedClasses] = term;
		  this.rooms[nrKeyedClasses] = room;
		  this.lecturers[nrKeyedClasses] = lecturer;
		  int hourOfWeek = startDay.ordinal()*9+startHour.ordinal();
		  /*System.out.println("calc start:" + className + ", "
				  + startDay + "(" + startDay.ordinal() +"), "
				  + startHour + "(" + startHour.ordinal() +"), "
				  + "hoourOfWeek " + hourOfWeek
				  );*/
		  this.totalStructure[nrKeyedClasses][0] = className;
		  this.totalStructure[nrKeyedClasses][1] = Integer.toString(hourOfWeek);
		  this.totalStructure[nrKeyedClasses][2] = term;
		  this.totalStructure[nrKeyedClasses][3] = room;
		  this.totalStructure[nrKeyedClasses][4] = lecturer;
		  this.nrKeyedClasses++;
	  }
  }


  /**
   * Checks to see if class is in keyedClassNames array
   * @return       int
   * @param        className
   */
  public int isMember(String className) {
	  for (int posn = 0; posn < this.nrKeyedClasses; posn++)
		  if (this.keyedClassNames[posn].equals(className))
			  return posn;
	  return -1;
  }
}
